% 1 - INITIALIZE UQLAB
clearvars
rng(1,'twister')
uqlab

% 2 - COMPUTATIONAL MODEL
% Create a MODEL object for the constraint (limit state) function model 
% using the function file:
ModelOpts.Type = 'UQLink';
ModelOpts.Name = 'Test';
ModelOpts.Command = 'abaqus cae noGui=Beam.py';
ModelOpts.Template = 'Beam.py.tpl';
ModelOpts.Output.FileName = {'abaqus1.rpt','abaqus2.rpt'};
ModelOpts.Output.Parser = 'readabaqusOutput';
ModelOpts.ExecutionPath = fullfile('D:\',...
    'Test') ;
ModelOpts.Format = {'%.6f'};
ModelOpts.Display = 'quiet';
myUQLinkModel = uq_createModel(ModelOpts);

% 3 - PROBABILISTIC INPUT MODEL
% The environmental variables are modeled probalistically using three
% independent random variables.
% Specify the marginals each of which follows a lognormal distribution:
InputOpts.Marginals(1).Name = 'rho';  % Young's modulus of the column
InputOpts.Marginals(1).Type = 'Gaussian';
InputOpts.Marginals(1).Moments = [100000 0.01*100000];

InputOpts.Marginals(2).Name = 'F';  % length of the column
InputOpts.Marginals(2).Type = 'Gaussian';
InputOpts.Marginals(2).Moments = [1000 0.01*1000];

% Create an INPUT object based on the specified marginals:
myInput = uq_createInput(InputOpts);


X = uq_getSample(4,'LHS');
Y = uq_evalModel(myUQLinkModel,X);


